;; Generated package description from polymode.el  -*- no-byte-compile: t -*-
(define-package "polymode" "0.2.2.0.20241129.123411" "Extensible framework for multiple major modes" '((emacs "25")) :commit "03be6d158f5d16875d2cefdd38ec47fec77b5acc" :maintainer '("Vitalie Spinu" . "spinuvit@gmail.com") :keywords '("languages" "multi-modes" "processes") :url "https://github.com/polymode/polymode")
